import React from 'react';
import { LexicalComposer } from '@lexical/react/LexicalComposer';
import { RichTextPlugin } from '@lexical/react/LexicalRichTextPlugin';
import { ContentEditable } from '@lexical/react/LexicalContentEditable';
import { LexicalErrorBoundary } from '@lexical/react/LexicalErrorBoundary';
import { EditorState } from 'lexical';
import { MyOnChangePlugin } from './plugins/StateChangePlugin';
import { ToolbarPlugin } from './plugins/ToolbarPlugin';
import { ErrorHandler } from './ErrorHandler';
import { Placeholder } from './Placeholder';

type TextEditorProps = {
  editorState: EditorState | undefined;
  setEditorState: (value: EditorState) => void;
  showToolbar: boolean;
  placeholder?: string;
};

export function TextEditor({ editorState, setEditorState, showToolbar, placeholder }: TextEditorProps) {
  function onChange(editorState: EditorState) {
    setEditorState(editorState);
  }

  const initialConfig = {
    namespace: 'MyEditor',
    editorState: editorState,
    onError: ErrorHandler,
  };

  return (
    <LexicalComposer initialConfig={initialConfig}>
      {showToolbar && <ToolbarPlugin />}
      <div className="relative">
        <RichTextPlugin
          contentEditable={<ContentEditable className="border min-h-24" />}
          placeholder={<Placeholder placeholder={placeholder} />}
          ErrorBoundary={LexicalErrorBoundary}
        />
      </div>
      <MyOnChangePlugin onChange={onChange} />
    </LexicalComposer>
  );
}
